import { linkedComponent } from '../package.js';
import { GithubRepository } from '../shapes/GithubRepository.js';
import React, { useEffect, useState } from 'react';
import { NamedNode } from 'lincd/models';
import { UserAvatar } from 'lincd-sioc/components/UserAvatar';
import { UserAccount } from 'lincd-sioc/shapes/UserAccount';
const MAX_NUM_THUMBS = 7;
const query = GithubRepository.query((g) => {
    return g;
});
export const GitRepositoryContributors = linkedComponent(query, ({ source, accessToken, id }) => {
    // let repository = new GithubRepository(source);
    // let contributors = repository.contributors;
    const [contributors, setContributors] = useState();
    let numLeft, selection;
    if (contributors) {
        numLeft = contributors.length - MAX_NUM_THUMBS;
        selection = [...contributors].slice(0, MAX_NUM_THUMBS);
    }
    //https://github.com/Semantu/lincd.org
    let parts = id.match(/https:\/\/github.com\/([\w.-_~]+)\/([\w.-_~]+)/);
    let repoOwner = parts[1]; //'lincd';
    let repoName = parts[2].replace('.git', ''); //'semantu';
    useEffect(() => {
        //accessToken
        fetch(`https://api.github.com/repos/${repoOwner}/${repoName}/contributors`, {
            method: 'GET',
            headers: {
                Authorization: 'bearer ' + accessToken,
            },
        })
            .then((result) => result.json())
            .then((contributorsArr) => {
            if (!Array.isArray(contributorsArr)) {
                return;
            }
            contributorsArr.sort((c1, c2) => c1.contributions > c1.contributions ? -1 : 1);
            // avatar_url: "https://avatars.githubusercontent.com/u/341567?v=4"
            // contributions: 1
            // html_url: "https://github.com/flyon"
            // login: "flyon"
            let contributors = contributorsArr.map((contributorObj) => {
                // let user = new Person();
                // user.name = contributorObj.
                // contributor.accountOf = user;
                let contributor = new UserAccount(NamedNode.getOrCreate(contributorObj.html_url));
                contributor.name = contributorObj.login;
                contributor.avatar = contributorObj.avatar_url;
                return contributor;
            });
            setContributors(contributors);
        });
    }, [source]);
    let userClicked = function (collaborator) {
        window.open(collaborator.namedNode.uri, '_blank');
    };
    return (React.createElement("div", null,
        contributors && (React.createElement("p", null,
            React.createElement("span", { className: "text-grey text-sm" }, "Contributors"),
            ' ',
            React.createElement("span", { className: "text-white text-md ml-1" }, contributors.length))),
        selection && (React.createElement("div", { className: "mt-2" },
            selection.map((collaborator) => {
                return (React.createElement(UserAvatar, { key: collaborator.toString(), of: collaborator.node, onClick: () => userClicked(collaborator) }));
            }),
            numLeft > 0 && (React.createElement("span", { className: "text-grey more" },
                "+",
                numLeft,
                " more"))))));
});
//# sourceMappingURL=GitRepositoryContributors.js.map