import {linkedComponent} from '../package.js';
import {GithubRepository} from '../shapes/GithubRepository.js';
import React, {useEffect, useState} from 'react';
import {NamedNode} from 'lincd/models';
import {schema} from 'lincd-schema/ontologies/schema';
import {fetchGitGraph} from '../hooks/git-graphql.js';
import {NodeSet} from 'lincd/collections/NodeSet';
import {UserAvatar} from 'lincd-sioc/components/UserAvatar';

const MAX_NUM_THUMBS: number = 7;
//nameless functional component with named export.
//export const GitRepositoryCollaborators:FunctionalComponent<{accessToken:string},GithubRepository> = linkedComponent(GithubRepository, ({source,accessToken}) => {

//named functional component with named export.
const query = GithubRepository.query((g) => {
  return g;
});
export const GitRepositoryCollaborators = linkedComponent<
  typeof query,
  {accessToken: string}
>(query, ({source, accessToken, id}) => {
  let repository = new GithubRepository(source);
  // let collaborators = repository.collaborators;

  const [collaborators, setCollaborators] = useState<NodeSet>();

  let numLeft, selection;
  if (collaborators) {
    numLeft = collaborators.size - MAX_NUM_THUMBS;
    selection = [...collaborators].slice(0, MAX_NUM_THUMBS);
  }

  //https://github.com/Semantu/lincd.org
  let parts = id ? id.split('/') : [];
  let repoName = 'lincd';
  let repoOwner = 'semantu';

  useEffect(() => {
    fetchGitGraph(
      `
      query { 
        repository(owner:"${repoOwner}",name:"${repoName}"){
          url 
          collaborators {
            nodes {
              name
              avatarUrl
              login
              resourcePath
            }
          }
        }
      }`,
      accessToken,
    ).then((repositories) => {
      let repositoryResultNode = repositories.first();
      if (repositoryResultNode) {
        let repositoryResult = new GithubRepository(repositoryResultNode);
        console.log(repositoryResultNode === repository.node);
        setCollaborators(repositoryResult.collaborators);
      }
    });
  }, [source]);

  let userClicked = function (collaborator: NamedNode) {
    collaborator.hasProperty(schema.url) &&
      window.open(
        'https://github.com/' + collaborator.getValue(schema.url),
        '_blank',
      );
  };

  return (
    <div>
      <p>
        <span className="text-grey text-sm">Collaborators</span>{' '}
        <span className="text-white text-md ml-1">
          {collaborators && collaborators.size}
        </span>
      </p>

      {selection && (
        <div className="mt-2">
          {selection.map((collaborator: NamedNode) => {
            return (
              <UserAvatar
                of={collaborator}
                key={collaborator.toString()}
                onClick={() => userClicked(collaborator)}
              />
            );
          })}
          {numLeft > 0 && (
            <span className="text-grey more">+{numLeft} more</span>
          )}
        </div>
      )}
    </div>
  );
});
